@@ -463,7 +463,7 @@ tree_pkg_compar(const void *l, const void *r)
 	depend_atom *al = tree_get_atom(pl, false);
 	depend_atom *ar = tree_get_atom(pr, false);
 
-	return atom_compar_cb(al, ar);
+	return atom_compar_cb(&al, &ar);
 }
 
 static tree_pkg_ctx *
@@ -1075,7 +1075,7 @@ tree_read_file_binpkg(tree_pkg_ctx *pkg_ctx)
 
 		lseek(newfd, 0, SEEK_SET);  /* reposition at the whole file */
 		if (hash_multiple_file_fd(newfd, NULL, m->Q_SHA1, NULL, NULL,
-				NULL, NULL, &fsize, HASH_SHA1) == 0)
+				NULL, &fsize, HASH_SHA1) == 0)
 			snprintf(m->Q_SIZE, 19 + 1, "%zu", fsize);
 	}
 
@@ -1233,6 +1233,12 @@ tree_pkg_meta_get_int(tree_pkg_ctx *pkg_ctx, size_t offset, const char *keyn)
 					p[--s.st_size] = '\0';
 				m->storage->pos += s.st_size + 1;
 			}
+			else
+			{
+				/* hmmm, couldn't read the whole file?!? */
+				p[0] = '\0';
+				m->storage->pos++;
+			}
 			close(fd);
 		}
 	} else {
