@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2022 Gentoo Authors
+ * Copyright 2005-2024 Gentoo Authors
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
@@ -794,8 +794,8 @@ pkg_run_func_at(
 		"has() { hasq \"$@\"; }\n"
 		"hasq() { local h=$1; shift; case \" $* \" in *\" $h \"*) return 0;; *) return 1;; esac; }\n"
 		"hasv() { hasq \"$@\" && echo \"$1\"; }\n"
-		"elog() { printf ' * %%b\\n' \"$*\"; }\n"
-		"einfon() { printf ' * %%b' \"$*\"; }\n"
+		"elog() { printf ' * %%b\\n' \"$*\" >&2; }\n"
+		"einfon() { printf ' * %%b' \"$*\" >&2; }\n"
 		"einfo() { elog \"$@\"; }\n"
 		"ewarn() { elog \"$@\"; }\n"
 		"eqawarn() { elog \"QA: \"\"$@\"; }\n"
@@ -805,8 +805,8 @@ pkg_run_func_at(
 		"fperms() { local f a=$1; shift; for f in \"$@\"; do chmod $a \"${ED}/${f}\"; done; }\n"
 		/* TODO: This should suppress `die` */
 		"nonfatal() { \"$@\"; }\n"
-		"ebegin() { printf ' * %%b ...' \"$*\"; }\n"
-		"eend() { local r=${1:-$?}; [ $# -gt 0 ] && shift; [ $r -eq 0 ] && echo ' [ ok ]' || echo \" $* \"'[ !! ]'; return $r; }\n"
+		"ebegin() { printf ' * %%b ...' \"$*\" >&2; }\n"
+		"eend() { local r=${1:-$?}; [ $# -gt 0 ] && shift; [ $r -eq 0 ] && echo ' [ ok ]' || echo \" $* \"'[ !! ]'; return $r; } >&2\n"
 		"dodir() { mkdir -p \"$@\"; }\n"
 		"keepdir() { dodir \"$@\" && touch \"$@\"/.keep_${CATEGORY}_${PN}-${SLOT%%/*}; }\n"
 		/* TODO: This should be fatal upon error */
@@ -1224,7 +1224,7 @@ pkg_merge(int level, const depend_atom *qatom, const tree_match_ctx *mpkg)
 	/* Doesn't actually remove $PWD, just everything under it */
 	rm_rf(".");
 
-	mkdir("temp", 0755);
+	mkdir_p("temp", 0755);
 	mkdir_p(portroot, 0755);
 
 	tbz2size = 0;
@@ -1411,10 +1411,12 @@ pkg_merge(int level, const depend_atom *qatom, const tree_match_ctx *mpkg)
 		int imagefd = open("image", O_RDONLY);
 		size_t masklen = strlen(install_mask) + 1 +
 				15 + 1 + 14 + 1 + 14 + 1 + 1;  /* worst case scenario */
-		char *imask = xmalloc(masklen);
+		char *imask;
 		size_t maskp;
 
-		if (fstat(imagefd, &st) == -1) {
+		if (imagefd == -1) {
+			err("Failed to open image dir");
+		} else if (fstat(imagefd, &st) == -1) {
 			close(imagefd);
 			err("Cannot stat image dirfd");
 		} else if (eprefix != NULL && eprefix[0] == '/') {
@@ -1425,6 +1427,7 @@ pkg_merge(int level, const depend_atom *qatom, const tree_match_ctx *mpkg)
 			}
 		}
 
+		imask = xmalloc(masklen);
 		/* rely on INSTALL_MASK code to remove optional dirs */
 		maskp = snprintf(imask, masklen, "%s ", install_mask);
 		if (contains_set("noinfo", features))
@@ -1478,6 +1481,10 @@ pkg_merge(int level, const depend_atom *qatom, const tree_match_ctx *mpkg)
 
 		cpath = xstrdup("");  /* xrealloced in merge_tree_at */
 
+		/* TODO: use replacing to pass over pervinst->pkg for
+		 * VDB/CONTENTS and respect the config-protect-if-modified flag
+		 * like unmerge does */
+
 		ret = merge_tree_at(AT_FDCWD, "image",
 				AT_FDCWD, portroot, contents, eprefix_len,
 				&objs, &cpath, cp_argc, cp_argv, cpm_argc, cpm_argv);
@@ -1806,7 +1813,7 @@ pkg_verify_checksums(
 	size_t flen;
 	int    mlen;
 
-	if (hash_multiple_file(pkg->path, md5, sha1, NULL, NULL, NULL, NULL,
+	if (hash_multiple_file(pkg->path, md5, sha1, NULL, NULL, NULL,
 			&flen, HASH_MD5 | HASH_SHA1) == -1)
 		errf("failed to compute hashes for %s: %s\n",
 				atom_to_string(pkg->atom), strerror(errno));
